@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Copyright 2021 KylinSoft Co., Ltd.
+ * Copyright (C) 2023, KylinSoft Co., Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,21 +19,23 @@
 #ifndef LOCKCHECKER_H
 #define LOCKCHECKER_H
 
+#include "ukuilockinfo.h"
 #include <QFile>
 #include <QDBusArgument>
 
-namespace InhibitInfo {
-    struct InhibitorInfo {
-        QString name;
-        QString icon;
-    };
+//为了兼容性，要在tools中加入ukuilockinfo.h，而在该头文件中已经定义了InhibitorInfo，为了避免重复定义，注销此处定义
+//namespace InhibitInfo {
+//    struct InhibitorInfo {
+//        QString name;
+//        QString icon;
+//    };
 
-    QDBusArgument &operator<<(QDBusArgument &argument, const InhibitInfo::InhibitorInfo &mystruct);
+//    QDBusArgument &operator<<(QDBusArgument &argument, const InhibitInfo::InhibitorInfo &mystruct);
 
-    const QDBusArgument &operator>>(const QDBusArgument &argument, InhibitInfo::InhibitorInfo &mystruct);
-}
+//    const QDBusArgument &operator>>(const QDBusArgument &argument, InhibitInfo::InhibitorInfo &mystruct);
+//}
 
-Q_DECLARE_METATYPE(InhibitInfo::InhibitorInfo)
+//Q_DECLARE_METATYPE(InhibitInfo::InhibitorInfo)
 
 class LockChecker
 {
@@ -50,6 +52,8 @@ public:
 
 private:
     static QString getName(QFile *a);
+
+    static bool getInhibitorLocal(QVector<InhibitInfo::InhibitorInfo> &inhibitVec, QString type);
 };
 
 #endif // LOCKCHECKER_H
