@@ -379,13 +379,19 @@ void launchUKUISMServer() {
 
     qDebug() << "start ukuismserver with windowmanager=" << wm ;
     QProcess *p = new QProcess;
-    if ("ukui-kwin" == wm) {
-        p->start("ukuismserver");
-    } else {
+    QString fullPath = "/usr/bin/" + wm;
+    QFile file(fullPath);
+    if(file.exists()) {
         QStringList arg;
         arg << "-w";
         arg << wm;
         p->start("ukuismserver",arg);
+    } else {
+        qDebug() << "Can not find file " << fullPath << ", start ukwm instead" ;
+        QStringList arg;
+        arg << "-w";
+        arg << "ukwm";
+        p->start("ukuismserver",arg);
     }
     p->closeReadChannel(QProcess::StandardOutput);
     p->closeReadChannel(QProcess::StandardError);
